/**
 * Star Rating - jQuery plugin
 *
 * Copyright (c) 2007 Wil Stuckey
 * Modified by John Resig
 *
 * Dual licensed under the MIT and GPL licenses:
 *   http://www.opensource.org/licenses/mit-license.php
 *   http://www.gnu.org/licenses/gpl.html
 *
 */

// modified from http://sandbox.wilstuckey.com/jquery-ratings/js/jquery.rating.js
// then http://john.jquery.com/plugins/rating/js/jquery.rating.js for jQuery 1.1
 
/**
 * Create a degradeable star rating interface out of a simple form structure.
 * Returns a modified jQuery object containing the new interface.
 *   
 * @example $("form.rating").rating();
 * @cat plugin
 * @type jQuery 
 *
 */
jQuery.fn.rating = function(){
    return this.each(function(){
        var div = $("<div/>").attr({
            title: this.title,
            className: this.className + "-stars"
        }).insertAfter(this);
        
        $(this).find("select option").each(function(){
            div.append(this.value == "0" ?
                "<div class='cancel'><a href='#0' title='Cancel rating'>Cancel rating</a></div>" :
                "<div class='star'><a href='#" + this.value + "' class='mod' title='" + this.text  + "'>" + this.value + "</a></div>" );
        });

        var averageRating = this.title.split(/:\s*/)[1].split("."),
            url = this.action,
            averageIndex = averageRating[0],
            averagePercent = averageRating[1];
        
        var split_id = this.id.split("-");
        var id = split_id[2] + '-' + split_id[3];
                        
        var rating_intro_text = $("<span/>").attr({
            "class": "rating-intro-text"
        })
        .append(
          $("#rating-options-" + id).attr("title") + ": "
        );
        
        var rating_intro = $("#rating-intro-" + id)
        .append(rating_intro_text)
        .append(
          $("<span/>").attr({
            "id": "rating-text-" + id,
            "class": "rating-text"
          })
        )
        .append(
          $("<span/>").attr({
              "id": "rating-message-" + id,
              "class": "rating-message"
          })
        )
        .append(
          $("<span/>").attr({
            "id": "rating-text-" + id,
            "class": "rating-text"
          })
        );
        
        // hover events and focus events added
        var stars = div.find("div.star")
            .mouseover(drainFill).focus(drainFill)
            .mouseout(drainReset).blur(drainReset)
            .click(click);

        // cancel button events
        div.find("div.cancel")
            .mouseover(drainAdd).focus(drainAdd)
            .mouseout(resetRemove).blur(resetRemove)
            .click(click);

        reset();

        function drainFill(){
          drain(); fill(this);
          $("#rating-text-" + id).html(this.firstChild.title);
        }
        function drainReset(){
          drain(); reset();
          $("#rating-text-" + id).html("");
        }
        function resetRemove(){ reset(); $(this).removeClass("on"); }
        function drainAdd(){ drain(); $(this).addClass("on"); }

        function click(){
            averageIndex = stars.index(this) + 1;
            averagePercent = 0;

            if (averageIndex == 0) {
              drain();
            }

            //jQuery.post(url,{
                //rating: $(this).find("a")[0].href.slice(1)
            //});
            
            var index = $("#rating-options-" + id).rating_option(
              $(this).find("a")[0].href.split("#")[1]
            );
            $("#rating-options-" + id).get(0).selectedIndex = index;
            rating_submit_rating(id);

            return false;
        }

        // fill to the current mouse position.
        function fill(elem){
            stars.find("a").css("width", "100%");
            stars.slice(0, stars.index(elem) + 1).addClass("hover");
        }
    
        // drain all the stars.
        function drain(){
            stars.removeClass("on hover");
        }

        // Reset the stars to the default index.
        function reset(){
            stars.slice(0, averageIndex).addClass("on");

            var percent = averagePercent ? averagePercent * 10 : 0;
            if (percent > 0) {
                $(stars[averageIndex]).addClass("on").children("a").css("width", percent + "%");
            }
        }
    });
};

// fix ie6 background flicker problem.
if ( jQuery.browser.msie == true )
    document.execCommand("BackgroundImageCache", false, true);

jQuery.fn.sort = function() {
  return this.pushStack( jQuery.merge( [].sort.apply( this, arguments ), []), [] );
};

jQuery.fn.reverse = function() {
  return this.pushStack(this.get().reverse(), arguments);
};

jQuery.fn.rating_option = function (value) {
  var select = $(this)[0];
  for ( var i=0; i<select.length; i++ )
  if (select[i].value == value)
  return i;
};

function rating_submit_rating(id){
  $("#rating-form-" + id).ajaxSubmit(
    {
      dataType: "json",
      after: function(data){
        if (data.error){
          $("#rating-message-" + id).css("background", "#f95");
          $("#rating-message-" + id).html(data.error).fadeIn("fast");
          return false;
        }
        $("#rating-message-" + id).css("background","#ff5");
        //$("#rating-message-" + id).html(data.response).fadeIn("slow").fadeOut("slow");
        $("#rating-message-" + id).html(data.response).fadeIn("fast");

        mean = data.mean.split(".");
        var stars = $("#rating-mean-stars-" + id).find("div.star");
        stars.removeClass("on hover");
        stars.find("a").css("width", "100%");              
        stars.slice(0, mean[0]).addClass("on");
        if (mean[1] > 0){
          $(stars[mean[0]]).addClass("on").children("a").css("width", mean[1] * 10 + "%");
        }
        $(".rating-num-votes-" + id).html(data.num_votes);
        if (typeof(jrating_postsubmit) == "function"){
          jrating_postsubmit(id);
        }
      }
    }
  );
}

$(document).ready(
  function() {
    try{
      $("form.rating").rating();
    }
    catch(e){};
  }
);

/*
// example jrating_postsubmit function
function jrating_postsubmit(id){
  $('#rating-' + id).hide("fast");
}
*/